Crate wasmer_cache_near

Crate wasmer_cache_near 

The wasmer-cache crate provides the necessary abstractions to cache WebAssembly Modules easily.

Structs

FileSystemCache
Representation of a directory that contains compiled wasm artifacts.
Hash
A hash used as a key when loading and storing modules in a [Cache].

Enums

DeserializeError
The Deserialize error can occur when loading a compiled Module from a binary.
SerializeError
The Serialize error can occur when serializing a compiled Module into a binary.

Traits

Cache
A generic cache for storing and loading compiled wasm modules.